#!/bin/bash

set -eu

main() {
	if [[ $# -ne 2 ]] ; then
		echo "Usage: is-divisible.sh numerator denominator">&2
		exit 1
	fi
	
	# .
	
	local numerator="$1"
	local denominator="$2"
	
	local sourcefile="$(mktemp)"
	local execfile="$(mktemp)"
	
	(
		php divisibility-generator.php "$2"
		cat <<EOM

typedef union {
	int as_i;
	char as_c4[4];
} integer_type;

int main(int argc, char** argv) {
	integer_type val = {0};
	val.as_i = atoi(argv[1]);
	
	return is_divisible_by_${denominator}(val.as_c4, 4) == DIVISIBLE_TRUE ? 0 : 1;
}

EOM
	) > "$sourcefile"
	
	gcc -x c "$sourcefile" -o "$execfile"
	
	if "$execfile" $numerator ; then
		echo "YES, it is divisible"
	else
		echo "NO, it is not divisible"
	fi
	
	rm "$sourcefile"
	rm "$execfile"
}

main "$@"
